/* -*- Mode: indent-tabs-mode: nil; js-indent-level: 2 -*- */
/* vim: set sts=2 sw=2 et tw=80: */
"use strict";

const kBackground = "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAFCAYAAACNbyblAAAAHElEQVQI12P4//8/w38GIAXDIBKE0DHxgljNBAAO9TXL0Y4OHwAAAABJRU5ErkJggg==";

function hexToRGB(hex) {
  hex = parseInt((hex.indexOf("#") > -1 ? hex.substring(1) : hex), 16);
  return [hex >> 16, (hex & 0x00FF00) >> 8, (hex & 0x0000FF)];
}

add_task(function* testLWTSupportNewProperties() {
  const kFrameColor = [71, 105, 91];
  const kTabTextColor = [207, 221, 192, .9];

  let tab = yield BrowserTestUtils.openNewForegroundTab(gBrowser, "about:home", true);

  let extension = ExtensionTestUtils.loadExtension({
    manifest: {
      "theme": {
        "images": {
          "theme_frame": kBackground,
        },
        "colors": {
          "frame": kFrameColor,
          "tab_text": kTabTextColor,
        },
      },
    },
  });

  yield extension.startup();

  let win = tab.ownerDocument.defaultView;
  let docEl = tab.ownerDocument.documentElement;
  let style = win.getComputedStyle(docEl);

  Assert.ok(docEl.hasAttribute("lwtheme"), "LWT attribute should be set");
  Assert.equal(docEl.getAttribute("lwthemetextcolor"), "bright",
    "LWT text color attribute should be set");

  Assert.equal(style.backgroundImage, 'url("' + kBackground.replace(/"/g, '\\"') + '")',
    "Expected background image");
  Assert.equal(style.backgroundColor, "rgb(" + kFrameColor.join(", ") + ")",
    "Expected correct background color");
  Assert.equal(style.color, "rgba(" + kTabTextColor.join(", ") + ")",
    "Expected correct text color");

  yield extension.unload();

  Assert.ok(!docEl.hasAttribute("lwtheme"), "LWT attribute should not be set");

  yield BrowserTestUtils.removeTab(tab);
});

add_task(function* testLWTSupportLegacyProperties() {
  const kAccentColor = "#a14040";
  const kTextColor = "#fac96e";

  let tab = yield BrowserTestUtils.openNewForegroundTab(gBrowser, "about:home", true);

  let extension = ExtensionTestUtils.loadExtension({
    manifest: {
      "theme": {
        "images": {
          "headerURL": kBackground,
        },
        "colors": {
          "accentcolor": kAccentColor,
          "textcolor": kTextColor,
        },
      },
    },
  });

  yield extension.startup();

  let win = tab.ownerDocument.defaultView;
  let docEl = tab.ownerDocument.documentElement;
  let style = win.getComputedStyle(docEl);

  Assert.ok(docEl.hasAttribute("lwtheme"), "LWT attribute should be set");
  Assert.equal(docEl.getAttribute("lwthemetextcolor"), "bright",
    "LWT text color attribute should be set");

  Assert.equal(style.backgroundImage, 'url("' + kBackground.replace(/"/g, '\\"') + '")',
    "Expected background image");
  Assert.equal(style.backgroundColor, "rgb(" + hexToRGB(kAccentColor).join(", ") + ")",
    "Expected correct background color");
  Assert.equal(style.color, "rgb(" + hexToRGB(kTextColor).join(", ") + ")",
    "Expected correct text color");

  yield extension.unload();

  Assert.ok(!docEl.hasAttribute("lwtheme"), "LWT attribute should not be set");

  yield BrowserTestUtils.removeTab(tab);
});
